############################################################

##  Estimate ideal points for respondents to 2010 CCES
##  Code last updated: December 6, 2013

############################################################

library(foreign)
library(pscl)
library(car)

setwd('~/Dropbox/Papers/Elmendorf-Spencer/Data/section_2_replication/')

## Read in CCES 2010 data:
cces <- read.csv('data/cces_2010_clean.csv', stringsAsFactors=F)

## Subset to respondents that reported partisan affilication (D, I, R)
#cces <- cces[cces$party.3 < 4,] # Nevermind

## Run ideal() function on whole sample
names <- as.character(cces[,4])
votes <- as.matrix(cces[,c(85:122)])
vote.names <- names(cces)[85:122]
cces.rc <- rollcall(votes, yea = 1, nay = 6, missing = NA,
                    legis.names = names, vote.names=vote.names,
                    desc='2010 CCES', source='http://projects.iq.harvard.edu/cces/data')
start <- rep(0,dim(cces)[1])
start[cces$party.3==1] <- -1
start[cces$party.3==2] <- 1

### NOTE: THE FOLLOWING FUNCTION TAKES APPROXIMATELY 3 HOURS TO CONVERGE ###
rc.all <- ideal(cces.rc, startvals=list(x=start), d=1, verbose=TRUE)

## Data frame of ideal points and range
x <- t(as.data.frame(rc.all$x))
y <- data.frame(case.ID=row.names(x), ideal.mean=apply(x, 1, mean), ideal.median=apply(x, 1, median),
                ideal.lower.95=apply(x, 1, quantile, 0.025), ideal.upper.95=apply(x, 1, quantile, .975),
                ideal.lower.90=apply(x, 1, quantile, 0.05), ideal.upper.90=apply(x, 1, quantile, 0.95))
y$case.ID <- as.character(y$case.ID)
y$case.ID <- strtrim(y$case.ID, (nchar(y$case.ID)-3))
rownames(y) <- NULL     
df <- merge(y, cces)

## Save file
#write.csv(df, file='data/cces_ideal_points_only.csv', row.names=F) # old file
write.csv(df, file='~/data/cces_all_with_ideal_points.csv', row.names=F)

## Clear environment
rm(list=ls())

############################################################
##  END OF FILE
############################################################